@@ -1,7 +1,7 @@
 // drumkv1_jack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -714,6 +714,8 @@ void drumkv1_jack::shutdown_close (void)
 #endif
 #endif
 
+#include <QTimer>
+
 #ifdef CONFIG_NSM
 #include "drumkv1_nsm.h"
 #endif
@@ -1040,6 +1042,9 @@ bool drumkv1_jack_application::setup (void)
 	if (m_pWidget)
 		m_pWidget->show();
 
+	// Start watchdog timer...
+	watchdog_start();
+
 	return true;
 }
 
@@ -1082,19 +1087,23 @@ void drumkv1_jack_application::openSession (void)
 	if (!dir.exists())
 		dir.mkpath(path_name);
 
+	bool bOpen = false;
+
 	QFileInfo fi(path_name, "session." DRUMKV1_TITLE);
 	if (!fi.exists())
 		fi.setFile(path_name, display_name + '.' + DRUMKV1_TITLE);
 	if (fi.exists()) {
 		const QString& sFilename = fi.absoluteFilePath();
 		if (m_pWidget) {
-			m_pWidget->loadPreset(sFilename);
+			bOpen = m_pWidget->loadPreset(sFilename);
 		} else {
-			drumkv1_param::loadPreset(m_pDrumk, sFilename);
+			bOpen = drumkv1_param::loadPreset(m_pDrumk, sFilename);
 		}
 	}
 
-	m_pNsmClient->open_reply();
+	m_pNsmClient->open_reply(bOpen
+		? drumkv1_nsm::ERR_OK
+		: drumkv1_nsm::ERR_GENERAL);
 	m_pNsmClient->dirty(false);
 
 	if (m_pWidget)
@@ -1122,9 +1131,12 @@ void drumkv1_jack_application::saveSession (void)
 //	const QFileInfo fi(path_name, display_name + '.' + DRUMKV1_TITLE);
 	const QFileInfo fi(path_name, "session." DRUMKV1_TITLE);
 
-	drumkv1_param::savePreset(m_pDrumk, fi.absoluteFilePath(), true);
+	const bool bSave
+		= drumkv1_param::savePreset(m_pDrumk, fi.absoluteFilePath(), true);
 
-	m_pNsmClient->save_reply();
+	m_pNsmClient->save_reply(bSave
+		? drumkv1_nsm::ERR_OK
+		: drumkv1_nsm::ERR_GENERAL);
 	m_pNsmClient->dirty(false);
 }
 
@@ -1190,6 +1202,29 @@ void drumkv1_jack_application::handle_sigterm (void)
 #endif	// HAVE_SIGNAL_H
 
 
+// Simple watchdog (3 minute cycle).
+void drumkv1_jack_application::watchdog_slot (void)
+{
+	if (m_pDrumk && m_pDrumk->client() == nullptr) {
+		const QByteArray aClientName
+			= m_sClientName.toLocal8Bit();
+		const char *client_name
+			= aClientName.constData();
+		m_pDrumk->open(client_name);
+		m_pDrumk->activate();
+	}
+
+	watchdog_start();
+}
+
+
+void drumkv1_jack_application::watchdog_start (void)
+{
+	if (g_pInstance)
+		QTimer::singleShot(60000, this, SLOT(watchdog_slot()));
+}
+
+
 // JACK shutdown handlers.
 void drumkv1_jack_application::shutdown (void)
 {
@@ -1199,16 +1234,18 @@ void drumkv1_jack_application::shutdown (void)
 
 void drumkv1_jack_application::shutdown_slot (void)
 {
-	bool bQuit = true;
-
 	if (m_pDrumk)
 		m_pDrumk->shutdown_close();
 
+#if 0//Don't quit anymore; let watchdog handle auto re-activation...
+	bool bQuit = true;
+
 	if (m_pWidget)
 		bQuit = m_pWidget->queryClose();
 
 	if (m_pApp && bQuit)
 		m_pApp->quit();
+#endif
 }
 
 
