@@ -1,7 +1,7 @@
 // drumkv1widget.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1082,7 +1082,7 @@ void drumkv1widget::newPreset (void)
 
 
 // Preset file I/O slots.
-void drumkv1widget::loadPreset ( const QString& sFilename )
+bool drumkv1widget::loadPreset ( const QString& sFilename )
 {
 #ifdef CONFIG_DEBUG
 	qDebug("drumkv1widget::loadPreset(\"%s\")", sFilename.toUtf8().constData());
@@ -1094,29 +1094,41 @@ void drumkv1widget::loadPreset ( const QString& sFilename )
 	resetParamKnobs(drumkv1::NUM_PARAMS);
 	resetParamValues(drumkv1::NUM_PARAMS);
 
+	bool bLoad = false;
+
 	drumkv1_ui *pDrumkUi = ui_instance();
 	if (pDrumkUi)
-		pDrumkUi->loadPreset(sFilename);
+		bLoad = pDrumkUi->loadPreset(sFilename);
 
-	updateLoadPreset(QFileInfo(sFilename).completeBaseName());
+	if (bLoad)
+		updateLoadPreset(QFileInfo(sFilename).completeBaseName());
+	else
+		updateDirtyPreset(true);
+
+	return bLoad;
 }
 
 
-void drumkv1widget::savePreset ( const QString& sFilename )
+bool drumkv1widget::savePreset ( const QString& sFilename )
 {
 #ifdef CONFIG_DEBUG
 	qDebug("drumkv1widget::savePreset(\"%s\")", sFilename.toUtf8().constData());
 #endif
 
+	bool bSave = false;
+
 	drumkv1_ui *pDrumkUi = ui_instance();
 	if (pDrumkUi)
-		pDrumkUi->savePreset(sFilename);
+		bSave = pDrumkUi->savePreset(sFilename);
 
-	const QString& sPreset
-		= QFileInfo(sFilename).completeBaseName();
+	if (bSave) {
+		const QString& sPreset
+			= QFileInfo(sFilename).completeBaseName();
+		m_ui.StatusBar->showMessage(tr("Save preset: %1").arg(sPreset), 5000);
+	}
+	updateDirtyPreset(!bSave);
 
-	m_ui.StatusBar->showMessage(tr("Save preset: %1").arg(sPreset), 5000);
-	updateDirtyPreset(false);
+	return bSave;
 }
 
 
@@ -1761,10 +1773,8 @@ void drumkv1widget::midiInLedTimeout (void)
 void drumkv1widget::helpConfigure (void)
 {
 	drumkv1_ui *pDrumkUi = ui_instance();
-	if (pDrumkUi == nullptr)
-		return;
-
-	drumkv1widget_config(pDrumkUi, this).exec();
+	if (pDrumkUi)
+		drumkv1widget_config(this, pDrumkUi).exec();
 }
 
 
@@ -1791,15 +1801,15 @@ void drumkv1widget::helpAbout (void)
 	list << tr("LV2 plug-in build disabled.");
 #endif
 
-	QString sText = "<p>\n";
-	sText += "<b>" DRUMKV1_TITLE "</b> - " + tr(DRUMKV1_SUBTITLE) + "<br />\n";
+	QString sText = "<h1>" DRUMKV1_TITLE "</h1>\n";
+	sText += "<p>" + tr(DRUMKV1_SUBTITLE) + "<br />\n";
 	sText += "<br />\n";
 	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
 //	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
 	if (!list.isEmpty()) {
 		sText += "<small><font color=\"red\">";
 		sText += list.join("<br />\n");
-		sText += "</font></small><br />\n";
+		sText += "</font></small>\n";
 	}
 	sText += "<br />\n";
 	sText += tr("Using: Qt %1").arg(qVersion());
