@@ -1,7 +1,7 @@
 // drumkv1widget.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -86,8 +86,8 @@ public:
 public slots:
 
 	// Preset file I/O.
-	void loadPreset(const QString& sFilename);
-	void savePreset(const QString& sFilename);
+	bool loadPreset(const QString& sFilename);
+	bool savePreset(const QString& sFilename);
 
 	// Direct note-on/off slot.
 	void directNoteOn(int iNote, int iVelocity);
