@@ -1,7 +1,7 @@
 // drumkv1widget_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -55,7 +55,7 @@ static const char *g_pszDefName = QT_TRANSLATE_NOOP("drumkv1widget_config", "(de
 
 // ctor.
 drumkv1widget_config::drumkv1widget_config (
-	drumkv1_ui *pDrumkUi, QWidget *pParent )
+	drumkv1widget *pParent, drumkv1_ui *pDrumkUi )
 	: QDialog(pParent), p_ui(new Ui::drumkv1widget_config), m_ui(*p_ui),
 		m_pDrumkUi(pDrumkUi)
 {
@@ -81,6 +81,11 @@ drumkv1widget_config::drumkv1widget_config (
 	m_iDirtyPrograms = 0;
 	m_iDirtyOptions  = 0;
 
+	// Whether presets exist...
+	m_bPresets = false;
+
+	m_iLoadPreset = 0;
+
 	// Setup options...
 	drumkv1_config *pConfig = drumkv1_config::getInstance();
 	if (pConfig && m_pDrumkUi) {
@@ -105,9 +110,10 @@ drumkv1widget_config::drumkv1widget_config (
 		// Load programs database...
 		drumkv1_programs *pPrograms = m_pDrumkUi->programs();
 		if (pPrograms) {
+			m_bPresets = !pConfig->presetList().isEmpty();
 			m_ui.ProgramsTreeWidget->loadPrograms(pPrograms);
-			m_ui.ProgramsEnabledCheckBox->setEnabled(bPlugin);
-			m_ui.ProgramsPreviewCheckBox->setEnabled(!bPlugin);
+			m_ui.ProgramsEnabledCheckBox->setEnabled(bPlugin && m_bPresets);
+			m_ui.ProgramsPreviewCheckBox->setEnabled(!bPlugin && m_bPresets);
 			m_ui.ProgramsEnabledCheckBox->setChecked(pPrograms->enabled());
 		}
 		// Initialize conveniency options...
@@ -454,11 +460,8 @@ void drumkv1widget_config::programsChanged (void)
 
 void drumkv1widget_config::programsActivated (void)
 {
-	if (m_pDrumkUi) {
-		drumkv1_programs *pPrograms = m_pDrumkUi->programs();
-		if (m_ui.ProgramsPreviewCheckBox->isChecked() && pPrograms)
-			m_ui.ProgramsTreeWidget->selectProgram(pPrograms);
-	}
+	if (m_ui.ProgramsPreviewCheckBox->isChecked())
+		loadPreset(m_ui.ProgramsTreeWidget->currentProgramName());
 
 	stabilize();
 }
@@ -651,7 +654,7 @@ void drumkv1widget_config::stabilize (void)
 	m_ui.ControlsDeleteToolButton->setEnabled(bEnabled);
 
 	pItem = m_ui.ProgramsTreeWidget->currentItem();
-	bEnabled = (m_pDrumkUi && m_pDrumkUi->programs() != nullptr);
+	bEnabled = (m_pDrumkUi && m_pDrumkUi->programs() != nullptr && m_bPresets);
 	m_ui.ProgramsPreviewCheckBox->setEnabled(
 		bEnabled && m_ui.ProgramsEnabledCheckBox->isChecked());
 	m_ui.ProgramsAddBankToolButton->setEnabled(bEnabled);
@@ -678,7 +681,8 @@ void drumkv1widget_config::stabilize (void)
 		= (m_iDirtyTuning   > 0
 		|| m_iDirtyControls > 0
 		|| m_iDirtyPrograms > 0
-		|| m_iDirtyOptions  > 0);
+		|| m_iDirtyOptions  > 0
+		|| m_iLoadPreset    > 0);
 	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bValid);
 }
 
@@ -816,7 +820,8 @@ void drumkv1widget_config::reject (void)
 	if (m_iDirtyTuning   > 0 ||
 		m_iDirtyControls > 0 ||
 		m_iDirtyPrograms > 0 ||
-		m_iDirtyOptions  > 0) {
+		m_iDirtyOptions  > 0 ||
+		m_iLoadPreset    > 0) {
 		QMessageBox::StandardButtons buttons
 			= QMessageBox::Discard | QMessageBox::Cancel;
 		if (m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->isEnabled())
@@ -831,11 +836,14 @@ void drumkv1widget_config::reject (void)
 			return;
 		case QMessageBox::Discard:
 			break;
-		default:    // Cancel.
+		default: // Cancel.
 			bReject = false;
 		}
 	}
 
+	if (bReject && m_iLoadPreset > 0)
+		loadPreset(m_sSavePreset);
+
 	if (bReject)
 		QDialog::reject();
 }
@@ -1000,4 +1008,26 @@ QString drumkv1widget_config::comboBoxCurrentItem ( QComboBox *pComboBox )
 }
 
 
+// Programs/preset preview stuff...
+void drumkv1widget_config::loadPreset ( const QString& sPreset )
+{
+	drumkv1_config *pConfig = drumkv1_config::getInstance();
+	if (pConfig == nullptr)
+		return;
+
+	const QString& sPresetFile
+		= pConfig->presetFile(sPreset);
+	if (sPresetFile.isEmpty())
+		return;
+
+	drumkv1widget *pParentWidget
+		= qobject_cast<drumkv1widget *> (parentWidget());
+	if (pParentWidget && pParentWidget->loadPreset(sPresetFile)) {
+		if (++m_iLoadPreset == 1)
+			m_sSavePreset = pConfig->sPreset;
+		pConfig->sPreset = sPreset;
+	}
+}
+
+
 // end of drumkv1widget_config.cpp
